@@ -14,20 +14,14 @@ def batch(iterable, n=1):
 def index_commits(graph, commits, batch_size=100):
     query = """
     UNWIND {commits} AS c
-    MERGE (:Commit { hash: c.hash,
-                     commit_hash: c.commit_hash,
-                     timestamp: c.timestamp,
-                     is_merge: c.is_merge,
-                     project_id: c.project_id,
-                     message: c.message,
-                     dmm_unit_complexity: c.dmm_unit_complexity,
-                     dmm_unit_interfacing: c.dmm_unit_interfacing,
-                     dmm_unit_size: c.dmm_unit_size
-                     })
+    MERGE (nc :Commit { hash: c.hash})
+      ON CREATE SET
+                nc = c
+      ON MATCH SET
+                nc = c
     """
     for b in batch(commits, batch_size):
         graph.run(query, commits=b)
-    create_index_commits(graph)
 
 
 def index_parent_commits(graph, parents, batch_size=100):
@@ -44,26 +38,23 @@ def index_parent_commits(graph, parents, batch_size=100):
 def index_authors(graph, authors, batch_size=100):
     query = """
     UNWIND {authors} AS a
-    MERGE (:Developer { hash: a.hash,
-                        email: a.email,
-                        name: a.name
-                      })
+    MERGE (nd:Developer { hash: a.hash})
+      ON CREATE SET nd = a
+      ON MATCH SET nd = a
     """
     for b in batch(authors, batch_size):
         graph.run(query, authors=b)
-    create_index_authors(graph)
 
 
 def index_branches(graph, branches, batch_size=100):
     query = """
     UNWIND {branches} AS a
-    MERGE (:Branch { hash: a.hash,
-                     name:a.name,
-                     project_id: a.project_id})
+    MERGE (nb:Branch { hash: a.hash})
+      ON CREATE SET nb = a
+      ON MATCH SET nb = a
     """
     for b in batch(branches, batch_size):
         graph.run(query, branches=b)
-    create_index_branches(graph)
 
 
 def index_branch_commits(graph, bc, batch_size=100):
@@ -80,27 +71,24 @@ def index_branch_commits(graph, bc, batch_size=100):
 def index_files(graph, files, batch_size=100):
     query = """
     UNWIND {files} AS f
-    MERGE (:File { hash: f.hash,
-                   project_id: f.project_id,
-                   type:f.type, name: f.name})
+    MERGE (nf:File { hash: f.hash})
+      ON CREATE SET nf = f
+      ON MATCH SET nf = f
     """
     for b in batch(files, batch_size):
         graph.run(query, files=b)
-    create_index_files(graph)
 
 
 def index_methods(graph, methods, batch_size=100):
     query = """
     UNWIND {methods} AS f
-    MERGE (:Method { hash: f.hash,
-                     project_id: f.project_id,
-                     name: f.name,
-                     file_name: f.file_name})
+    MERGE (nm:Method { hash: f.hash})
+      ON CREATE SET nm = f
+      ON MATCH SET nm = f
     """
 
     for b in batch(methods, batch_size):
         graph.run(query, methods=b)
-    create_index_methods(graph)
 
 
 def index_author_commits(graph, ac, batch_size=100):
@@ -156,47 +144,56 @@ def create_index_authors(graph):
     graph.run(query)
 
 
-def create_index_commits(graph):
-    hash_q = """
-    CREATE INDEX ON :Commit(hash)
-    """
+def create_index_commits(graph, hash=True):
+    if hash:
+        hash_q = """
+        CREATE INDEX ON :Commit(hash)
+        """
+        graph.run(hash_q)
+
     pid_q = """
     CREATE INDEX ON :Commit(project_id)
     """
-    graph.run(hash_q)
+
     graph.run(pid_q)
 
 
-def create_index_branches(graph):
-    hash_q = """
-    CREATE INDEX ON :Branch(hash)
-    """
+def create_index_branches(graph, hash=True):
+    if hash:
+        hash_q = """
+      CREATE INDEX ON :Branch(hash)
+      """
+        graph.run(hash_q)
+
     pid_q = """
     CREATE INDEX ON :Branch(project_id)
     """
-    graph.run(hash_q)
     graph.run(pid_q)
 
 
-def create_index_files(graph):
-    hash_q = """
-    CREATE INDEX ON :File(hash)
-    """
+def create_index_files(graph, hash=True):
+    if hash:
+        hash_q = """
+        CREATE INDEX ON :File(hash)
+        """
+        graph.run(hash_q)
+
     pid_q = """
     CREATE INDEX ON :File(project_id)
     """
-    graph.run(hash_q)
     graph.run(pid_q)
 
 
-def create_index_methods(graph):
-    hash_q = """
-    CREATE INDEX ON :Method(hash)
-    """
+def create_index_methods(graph, hash=True):
+    if hash:
+        hash_q = """
+        CREATE INDEX ON :Method(hash)
+        """
+        graph.run(hash_q)
+
     pid_q = """
     CREATE INDEX ON :Method(project_id)
     """
-    graph.run(hash_q)
     graph.run(pid_q)
 
 
